@@ -7,6 +7,7 @@
 #' @param download_dir a character string, path to directory where images are downloaded
 #' @return a character string, path to directory where images are downloaded
 #' @import RCurl
+#' @import data.table
 #' @export
 #' @examples
 #'
@@ -17,10 +18,10 @@
 #'  download_dir= tempdir())
 #'
 download_midday_images <- function(site, y = year(Sys.Date()), months = 1, days=1, download_dir){
-  midday_list <- get_midday_list(site)
+  midday_list <- get_midday_list(site, direct = FALSE)
   midday_table <- parse_phenocam_filenames(midday_list)
 
-  download_list <- midday_table[Year==y&Month%in%months&Day%in%days, filepaths]
+  download_list <- midday_table[midday_table$Year==y&midday_table$Month%in%months&midday_table$Day%in%days,]$filepaths
 
   n <- length(download_list)
 
@@ -30,15 +31,26 @@ download_midday_images <- function(site, y = year(Sys.Date()), months = 1, days=
   }
 
   if(!dir.exists(download_dir)){
-    dir.create(download_dir)
-    message('directory ', download_dir, ' was created!')
+    stop(download_dir, ' directory does not exist!')
   }
 
   pb <- txtProgressBar(0, n , style = 3)
+
   for(i in 1:n){
-    destfile <- paste0(download_dir, '/', basename(download_list[i]))
-    download.file(download_list[i], destfile = destfile, quiet = TRUE)
+    download_url <- download_list[i]
     setTxtProgressBar(pb, i)
+
+    if(!RCurl::url.exists(download_url)) {
+      warning(download_url, ' does not exist!')
+      next()
+    }
+
+    destfile <- paste0(download_dir, '/', basename(download_url))
+    if(file.exists(destfile)) {
+      warning(destfile, ' was already in ', download_dir)
+      next()
+    }
+    download.file(download_url, destfile = destfile, quiet = TRUE, mode = 'wb')
   }
 
   download_dir
